# VK-Botting

[![Documentation Status](https://readthedocs.org/projects/vk-botting/badge/?version=latest)](https://vk-botting.readthedocs.io/en/latest/?badge=latest)

This is a basic package for building async VK bots.<br>
It is in early stages of development so it can be buggy.<br>
That is also why it does not have full documentation atm.<br>
Partial docs are available at https://vk-botting.readthedocs.io/ru/latest (Russian) or https://vk-botting.readthedocs.io/en/latest (English)
